@@ -1,13 +1,14 @@
 import re
 from django.core import mail
-from django.core.urlresolvers import reverse
 from django.contrib.auth import get_user_model
 from django.test.utils import override_settings
+from django.urls import reverse
 from rest_framework import status
 from rest_framework.authtoken.models import Token
 from rest_framework.test import APITestCase
 
 from authemail.models import SignupCode, PasswordResetCode
+from authemail import wrapper
 
 
 def _get_code_from_email(mail):
@@ -40,11 +41,10 @@ class SignupTests(APITestCase):
         error_dicts = [
             # Email required
             {'payload': {'email': '',
-                         'password': self.pw_visitor
-                         },
+                         'password': self.pw_visitor},
              'status_code': status.HTTP_400_BAD_REQUEST,
              'error': ('email', 'This field may not be blank.')
-             },
+            },
             # Password required
             {'payload': {'email': self.em_visitor,
                          'password': ''},
